==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkProgrammableSource.java <==
// java wrapper for vtkProgrammableSource object
//

package vtk;
import vtk.*;

public class vtkProgrammableSource extends vtkDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetExecuteMethod_2(Object id0, String id1);
  public void SetExecuteMethod(Object id0, String id1)
    { SetExecuteMethod_2(id0,id1); }

  private native long GetPolyDataOutput_3();
  public vtkPolyData GetPolyDataOutput() {
    long temp = GetPolyDataOutput_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredPointsOutput_4();
  public vtkStructuredPoints GetStructuredPointsOutput() {
    long temp = GetStructuredPointsOutput_4();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredGridOutput_5();
  public vtkStructuredGrid GetStructuredGridOutput() {
    long temp = GetStructuredGridOutput_5();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetUnstructuredGridOutput_6();
  public vtkUnstructuredGrid GetUnstructuredGridOutput() {
    long temp = GetUnstructuredGridOutput_6();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRectilinearGridOutput_7();
  public vtkRectilinearGrid GetRectilinearGridOutput() {
    long temp = GetRectilinearGridOutput_7();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkProgrammableSource() { super(); }

  public vtkProgrammableSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv7h.pkg.tar.xz: vtk/vtkProgrammableSource.java <==
// java wrapper for vtkProgrammableSource object
//

package vtk;
import vtk.*;

public class vtkProgrammableSource extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetExecuteMethod_2(Object id0, String id1);
  public void SetExecuteMethod(Object id0, String id1)
    { SetExecuteMethod_2(id0,id1); }

  private native long GetPolyDataOutput_3();
  public vtkPolyData GetPolyDataOutput() {
    long temp = GetPolyDataOutput_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredPointsOutput_4();
  public vtkStructuredPoints GetStructuredPointsOutput() {
    long temp = GetStructuredPointsOutput_4();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredGridOutput_5();
  public vtkStructuredGrid GetStructuredGridOutput() {
    long temp = GetStructuredGridOutput_5();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetUnstructuredGridOutput_6();
  public vtkUnstructuredGrid GetUnstructuredGridOutput() {
    long temp = GetUnstructuredGridOutput_6();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRectilinearGridOutput_7();
  public vtkRectilinearGrid GetRectilinearGridOutput() {
    long temp = GetRectilinearGridOutput_7();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkProgrammableSource() { super(); }

  public vtkProgrammableSource(long id) { super(id); }
  public native long   VTKInit();

}
